@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon_master - remote control master for Nokia N900 phone #
-# $Id: smscon_master.py 117 2011-12-29 15:24:00Z yablacky $
+# $Id: smscon_master.py 123 2011-12-29 21:53:26Z yablacky $
 ##############################################################
 
 import os
@@ -23,9 +23,11 @@ LogDisplayName       = LogFile   .replace(NAME, '').strip('_')
 
 ##############################################################
 
-def ShowFile(*File):
+def ShowFile(*File, **kwargs):
     """
     Show file. Very verbose.
+    @param list Strings of path name parts.
+    @param list_of_2-tuples ReplacementRules where each list entry ([0] is pattern and [1] is replacement).
     @return bool True iff file exists and is non empty.
     """
     Filename = os.path.join(*File)
@@ -39,8 +41,16 @@ def ShowFile(*File):
     if Lines == []:
         LOGGER.info('File "%s" is empty.' % Filename)
         return False
-    for Line in Lines:
-        print Line,
+
+    ReplacementRules = kwargs.get('ReplacementRules')
+    if not ReplacementRules:
+        for Line in Lines:
+            print Line,
+    else:
+        for Line in Lines:
+            for Rule in ReplacementRules:
+                Line = re.sub(Rule[0], Rule[1], Line)
+            print Line,
     return True
 
 def ShowSmsCommands(theConf):
@@ -95,7 +105,7 @@ def ShowOptions(Level = 1):
         print '   -restart           : Stop & restart %s' % DaemonFile
         print '   -stop              : Stop %s' % DaemonFile
         print '   -status            : Get %s status' % DaemonFile
-        print '   -log               : Show log file'
+        print '   -log               : Show log file. Anonymized if no or wrong -pw option seen before.'
         print '   -del log           : Delete log file'
         print '   -sms               : Show SMS commands'
         print '   -set name "value"  : Set user setting (name = "value")'
@@ -107,6 +117,7 @@ def ShowOptions(Level = 1):
         print '   -unboot            : Disable %s to start at phone boot' % DaemonFile
         print '   -add imsi          : Add IMSI code of current SIM to %s file' % CodeDisplayName
         print '   -remove imsi       : Remove IMSI code of current SIM from %s file' % CodeDisplayName
+        print '   -pw password       : Password to enable non-anomymized output. MASTERNUMBER is password.'
         print '   -version           : Show version number'    
         print '   -help              : This help menu'
         print '   -help2             : More help (special options, rarely used).'
@@ -162,6 +173,7 @@ def DoCommandLine():
 
     ClientUsrID = OurUsrID = os.geteuid()
     ClientGrpID = OurGrpID = os.getegid()
+    Password = None
     DelaySeconds = 0.5
     args = sys.argv[1:]
     ok = len(args) > 0
@@ -181,7 +193,15 @@ def DoCommandLine():
         elif Mode == '-branch':     print VERSION
         elif Mode == '-build':      print VERSION
         elif Mode == '-status':     print "Daemon %s is %s" % (DaemonFile, IF(daemon.runs(), 'running', 'off'))
-        elif Mode == '-log':        ok = ShowFile(LOGGER.LogFilename)    
+        elif Mode == '-log':
+            if Password != None and Password == ourConf.get('MASTERNUMBER'):
+                ok = ShowFile(LOGGER.LogFilename)
+            else:   # No or invalid password: show anonymous log:
+                ok = ShowFile(LOGGER.LogFilename, ReplacementRules = [
+                    ('\\+?[0-9]{8,}', '+00123456789'),                          # replace potential phone numbers
+                    ('([a-zA-Z][a-zA-Z0-9_\\-]*\\.)+[a-zA-Z0-9_\\-]*[a-zA-Z]', 'example.com'),  # replace potential host names
+                    ('(?:[0-9]{1,3}\\.){1,3}([0-9]{1,3})', '192.168.128.\\1'),  # replace potential IPv4
+                ])    
         elif Mode == '-imsi':       ok = ShowIMSICodes()
         elif Mode == '-sms':        ok = ShowSmsCommands(ourConf)
         elif Mode == '-config':     ok = ShowFile(ourConf.Filename)
@@ -192,6 +212,10 @@ def DoCommandLine():
             Password = args.pop(0)
             ok = UserConfiguration().show(Password = Password)
 
+        elif Mode == '-pw':
+            if len(args) == 0: return TellError("%s requires argument" % Mode)
+            Password = args.pop(0)
+
         # The next commands potentially modify data and therefore need root permissions:
         elif os.geteuid() != 0 and not XDEBUG:
             return TellError('%s must run as "root" for this command.' % NAME)
