@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon_service - remote control daemon for Nokia N900 phone#
-# $Id: smscon_service.py 118 2011-12-29 15:53:33Z yablacky $
+# $Id: smscon_service.py 121 2011-12-29 20:14:19Z yablacky $
 ##############################################################
 
 # standard modules
@@ -158,8 +158,15 @@ def OnSmsReceived(PDUmessage, MessageCenter, SomeString, SenderNumber):
 
 def SMSsend(RecipientNumber, MessageList, SuccessLogMsg):
     """
-    Send SMS message to RecipientNumber.
-    @return bool False if the message has definitely not been sent. True otherwise.
+    Send SMS message to RecipientNumber. Handles re-sending on errors.
+    @param string RecipientNumber Phone number.
+    @param list_of_strings MessageList Message to send. If total text is too long for
+                one sms, the message is split into multiple sms thereby trying not
+                to split single list entries.
+    @param string SuccessLogMsg Message for LOGGER in case of successful sending.
+                A placeholder '{RECIPIENTNUMBER}' in that message is replaced
+                by the actual phone number.
+    @return bool False if the message has definitely not been sent. True if sent or queued for sending.
     """
     if not RecipientNumber:
         return False
@@ -173,7 +180,7 @@ def SMSsend(RecipientNumber, MessageList, SuccessLogMsg):
             return False
         LOGGER.warning('Trying to re-send SMS message after %s minutes.' % float(smscnf.RESENDTIME))
         tryCount = { 'value': 0 }
-        gobject.timeout_add(int(float(smscnf.RESENDTIME)) * 60000,
+        gobject.timeout_add(max(1000, int(float(smscnf.RESENDTIME) * 60000)),
                             lambda args: not SendToGSMmodem(**args), dict(
                                 RecipientNumber   = RecipientNumber,
                                 Message           = MessageText,
@@ -199,7 +206,7 @@ def SMSsend(RecipientNumber, MessageList, SuccessLogMsg):
     def SplitMessages(MessageList, MessageLengthMax, AssumeTotalPartCount):
         """
         Join the messages in the given list and split that to parts of MessageLengthMax.
-        If possible to not split within a single message.
+        If possible do not split within a single message.
         @return list of messages each of which is no longer than MessageLengthMax chars.
         """
         SplittedMessages = []
@@ -265,21 +272,22 @@ def SendToGSMmodem(RecipientNumber, Message, SuccessLogMsg, TryCount = None):
     Send SMS message to GSM modem.
     @return bool Success indicator
     """
-    RetryInfo = ''
     if TryCount:
         TryCount['value'] += 1
-        if int(smscnf.RESENDMAXTRY) > 0 and TryCount['value'] > int(smscnf.RESENDMAXTRY):
-            LOGGER.error('(SMS) Tried to send %d times. Limit %d reached. Giving up recipient=%s.' %
-                            (TryCount['value'], int(smscnf.RESENDMAXTRY), RecipientNumber))
-            return True
-        RetryInfo = " (%d. retry)" % TryCount['value']
 
     if SendSMSviaGSMmodem(RecipientNumber, Message):
         LOGGER.info(SuccessLogMsg.replace('{RECIPIENTNUMBER}', RecipientNumber))
         return True
-    else:
-        LOGGER.error('Failed to send SMS to "%s"%s.' % (RecipientNumber, RetryInfo))
-        return False
+
+    RetryInfo = ''
+    if TryCount:
+        RetryInfo = " (%d. retry out of %d)" % (TryCount['value'], int(smscnf.RESENDMAXTRY))
+        if int(smscnf.RESENDMAXTRY) > 0 and TryCount['value'] >= int(smscnf.RESENDMAXTRY):
+            LOGGER.error('Failed to send SMS to "%s"%s. Giving up.' % (RecipientNumber, RetryInfo))
+            return True     # fake success to stop further timer calls.
+
+    LOGGER.error('Failed to send SMS to "%s"%s.' % (RecipientNumber, RetryInfo))
+    return False
 
 def DeOctifyMessage(inputBytes):
     """
@@ -347,7 +355,7 @@ def EMAILsend(EmailTo, Subject, Text, SuccessLogMsg, **kwargs):
         return False
     LOGGER.warning('Trying to re-send email message after %s minutes.' % float(smscnf.RESENDTIME))
     tryCount = { 'value': 0 }
-    gobject.timeout_add(int(float(smscnf.RESENDTIME)) * 60000,
+    gobject.timeout_add(max(1000, int(float(smscnf.RESENDTIME) * 60000)),
                         lambda args: not SendToSMTPserver(**args), dict(
                             EmailTo       = EmailTo,
                             Subject       = Subject,
@@ -1933,7 +1941,7 @@ def InstallSignalReceivers():
             if smscnf.CHECKTIME == checktime:
                 return True
             LOGGER.info('(CHECKHOST) Checkhost is on. Checking each %s minutes.' % float(smscnf.CHECKTIME))
-            gobject.timeout_add(int(float(smscnf.CHECKTIME) * 60000), CheckHost, smscnf.CHECKTIME)
+            gobject.timeout_add(max(1000, int(float(smscnf.CHECKTIME) * 60000)), CheckHost, smscnf.CHECKTIME)
         else:
             IsCheckHostActive = False
             LOGGER.info('(CHECKHOST) Checkhost is off.')
