@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon - remote control library for Nokia N900 phone       #
-# $Id: smsconlib.py 111 2011-12-29 01:18:26Z yablacky $
+# $Id: smsconlib.py 124 2011-12-29 21:54:51Z yablacky $
 ##############################################################
 
 # standard modules
@@ -34,7 +34,7 @@ NAME = 'smscon'
 VERSION = '999.1'   # for trunk and private builds etc.
 
 NAME, VERSION = getSysBuildNameAndVersion(NAME, VERSION,
-    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.10/src/opt/smscon/smsconlib.py 111 2011-12-29 01:18:26Z yablacky $',
+    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.11/src/opt/smscon/smsconlib.py 124 2011-12-29 21:54:51Z yablacky $',
     dirLevels   = 3 )
     
 XDEBUG   = False        # cross debug (use only if not running on phone)
@@ -710,14 +710,14 @@ class UserConfiguration(Configuration):
     ItemTypeName        = "user setting"
     CreateTemplate      = '# %s user settings (initially written by version %s)\n' % (NAME, VERSION)
     SmsCommandPreFix    = 'COM_'       # _ConfigVars with that prefix define commands that can be sent via SMS
-    DefaultValueFormat  = '^\+?[X.@]+$' # '+XXXXXXXXXXX', 'XXXX@XXXXXXXX.XX', 'XXXX.XXXXXXXX.XX', ...
-    _PhoneNumber        = '^\+?[0-9]+$'
+    DefaultValueFormat  = '^\\+?[X.@]+$' # '+XXXXXXXXXXX', 'XXXX@XXXXXXXX.XX', 'XXXX.XXXXXXXX.XX', ...
+    _PhoneNumber        = '^\\+?[0-9]+$'
     _CmdPattern         = ''
     _BoolPattern        = '^(yes|no)$'
-    _IntPattern         = '^\d+$'
-    _FloatPattern       = '^\d+(\.\d+)?$'
+    _IntPattern         = '^\\d+$'
+    _FloatPattern       = '^\\d+(\\.\\d+)?$'
     _EmailPattern       = '^[^@]+@[^@]+$'
-    _IPforSSHPattern    = '^(\*|localhost|\d+(\.\d+)*)$'
+    _IPforSSHPattern    = '^(\\*|localhost|\\d+(\\.\\d+)*)$'
     _OPT_CRYPT          = Configuration._OPT_CRYPT
     _OPT_PLAIN          = Configuration._OPT_PLAIN
     _APPVERSIONVARNAME  = '@APPVERSION'
